@@ -12,11 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import configparser
 import logging
-import sys
 
 from oslo_config import cfg
-from six.moves import configparser
 
 from glance_store import exceptions
 from glance_store.i18n import _, _LE
@@ -24,7 +23,7 @@ from glance_store.i18n import _, _LE
 swift_opts = [
     cfg.StrOpt('default_swift_reference',
                default="ref1",
-               help=_("""
+               help="""
 Reference to default Swift account/backing store parameters.
 
 Provide a string value representing a reference to the default set
@@ -40,42 +39,42 @@ Possible values:
 Related options:
     * None
 
-""")),
+"""),
     cfg.StrOpt('swift_store_auth_version', default='2',
-               help=_('Version of the authentication service to use. '
-                      'Valid versions are 2 and 3 for keystone and 1 '
-                      '(deprecated) for swauth and rackspace.'),
+               help='Version of the authentication service to use. '
+                    'Valid versions are 2 and 3 for keystone and 1 '
+                    '(deprecated) for swauth and rackspace.',
                deprecated_for_removal=True,
-               deprecated_reason=_("""
+               deprecated_reason="""
 The option 'auth_version' in the Swift back-end configuration file is
 used instead.
-""")),
+"""),
     cfg.StrOpt('swift_store_auth_address',
-               help=_('The address where the Swift authentication '
-                      'service is listening.'),
+               help='The address where the Swift authentication '
+                    'service is listening.',
                deprecated_for_removal=True,
-               deprecated_reason=_("""
+               deprecated_reason="""
 The option 'auth_address' in the Swift back-end configuration file is
 used instead.
-""")),
+"""),
     cfg.StrOpt('swift_store_user', secret=True,
-               help=_('The user to authenticate against the Swift '
-                      'authentication service.'),
+               help='The user to authenticate against the Swift '
+                    'authentication service.',
                deprecated_for_removal=True,
-               deprecated_reason=_("""
+               deprecated_reason="""
 The option 'user' in the Swift back-end configuration file is set instead.
-""")),
+"""),
     cfg.StrOpt('swift_store_key', secret=True,
-               help=_('Auth key for the user authenticating against the '
-                      'Swift authentication service.'),
+               help='Auth key for the user authenticating against the '
+                    'Swift authentication service.',
                deprecated_for_removal=True,
-               deprecated_reason=_("""
+               deprecated_reason="""
 The option 'key' in the Swift back-end configuration file is used
 to set the authentication key instead.
-""")),
+"""),
     cfg.StrOpt('swift_store_config_file',
                default=None,
-               help=_("""
+               help="""
 Absolute path to the file containing the swift account(s)
 configurations.
 
@@ -96,18 +95,34 @@ Possible values:
 Related options:
     * swift_store_multi_tenant
 
-""")),
+"""),
 ]
 
 _config_defaults = {'user_domain_id': 'default',
-                    'user_domain_name': None,
+                    'user_domain_name': 'default',
                     'project_domain_id': 'default',
-                    'project_domain_name': None}
+                    'project_domain_name': 'default'}
+
+
+class SwiftConfigParser(configparser.ConfigParser):
+
+    def get(self, *args, **kwargs):
+        value = super(configparser.ConfigParser, self).get(*args, **kwargs)
+        return self._process_quotes(value)
+
+    @staticmethod
+    def _process_quotes(value):
+        if value:
+            if value[0] in "\"'":
+                if len(value) == 1 or value[-1] != value[0]:
+                    raise ValueError('Non-closed quote: %s' %
+                                     value)
+                value = value[1:-1]
+        return value
+
+
+CONFIG = SwiftConfigParser(defaults=_config_defaults)
 
-if sys.version_info >= (3, 2):
-    CONFIG = configparser.ConfigParser(defaults=_config_defaults)
-else:
-    CONFIG = configparser.SafeConfigParser(defaults=_config_defaults)
 LOG = logging.getLogger(__name__)
 
 
@@ -199,6 +214,6 @@ class SwiftParams(object):
                     reference['auth_version'] = av
 
                 account_params[ref] = reference
-            except (ValueError, SyntaxError, configparser.NoOptionError) as e:
+            except (ValueError, SyntaxError, configparser.NoOptionError):
                 LOG.exception(_LE("Invalid format of swift store config cfg"))
         return account_params
