@@ -20,18 +20,17 @@ from unittest import mock
 
 import fixtures
 import hashlib
+import http.client
+import importlib
+import io
 import tempfile
 import uuid
 
 from oslo_config import cfg
 from oslo_utils import encodeutils
+from oslo_utils.secretutils import md5
 from oslo_utils import units
 import requests_mock
-import six
-from six import moves
-from six.moves import http_client
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 import swiftclient
 
 from glance_store._drivers.swift import buffered
@@ -91,15 +90,15 @@ class SwiftTests(object):
             },
         }
         fixture_objects = {
-            'glance/%s' % FAKE_UUID: six.BytesIO(b"*" * FIVE_KB),
-            'glance/%s' % FAKE_UUID2: six.BytesIO(b"*" * FIVE_KB),
-            'glance/%s' % FAKE_UUID3: six.BytesIO(),
+            'glance/%s' % FAKE_UUID: io.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID2: io.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID3: io.BytesIO(),
         }
 
         def fake_head_container(url, token, container, **kwargs):
             if container not in fixture_containers:
                 msg = "No container %s found" % container
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             return fixture_container_headers
 
@@ -121,7 +120,8 @@ class SwiftTests(object):
                 if kwargs.get('headers'):
                     manifest = kwargs.get('headers').get('X-Object-Manifest')
                     etag = kwargs.get('headers') \
-                                 .get('ETag', hashlib.md5(b'').hexdigest())
+                                 .get('ETag', md5(
+                                     b'', usedforsecurity=False).hexdigest())
                     fixture_headers[fixture_key] = {
                         'manifest': True,
                         'etag': etag,
@@ -130,10 +130,10 @@ class SwiftTests(object):
                     fixture_objects[fixture_key] = None
                     return etag
                 if hasattr(contents, 'read'):
-                    fixture_object = six.BytesIO()
+                    fixture_object = io.BytesIO()
                     read_len = 0
                     chunk = contents.read(CHUNKSIZE)
-                    checksum = hashlib.md5()
+                    checksum = md5(usedforsecurity=False)
                     while chunk:
                         fixture_object.write(chunk)
                         read_len += len(chunk)
@@ -141,14 +141,15 @@ class SwiftTests(object):
                         chunk = contents.read(CHUNKSIZE)
                     etag = checksum.hexdigest()
                 else:
-                    fixture_object = six.BytesIO(contents)
+                    fixture_object = io.BytesIO(contents)
                     read_len = len(contents)
-                    etag = hashlib.md5(fixture_object.getvalue()).hexdigest()
+                    etag = md5(fixture_object.getvalue(),
+                               usedforsecurity=False).hexdigest()
                 if read_len > MAX_SWIFT_OBJECT_SIZE:
                     msg = ('Image size:%d exceeds Swift max:%d' %
                            (read_len, MAX_SWIFT_OBJECT_SIZE))
                     raise swiftclient.ClientException(
-                        msg, http_status=http_client.REQUEST_ENTITY_TOO_LARGE)
+                        msg, http_status=http.client.REQUEST_ENTITY_TOO_LARGE)
                 fixture_objects[fixture_key] = fixture_object
                 fixture_headers[fixture_key] = {
                     'content-length': read_len,
@@ -158,14 +159,14 @@ class SwiftTests(object):
                 msg = ("Object PUT failed - Object with key %s already exists"
                        % fixture_key)
                 raise swiftclient.ClientException(
-                    msg, http_status=http_client.CONFLICT)
+                    msg, http_status=http.client.CONFLICT)
 
         def fake_get_object(conn, container, name, **kwargs):
             # GET returns the tuple (list of headers, file object)
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object GET failed"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
             byte_range = None
@@ -182,7 +183,7 @@ class SwiftTests(object):
                 chunk_keys = sorted([k for k in fixture_headers.keys()
                                      if k.startswith(fixture_key) and
                                      k != fixture_key])
-                result = six.BytesIO()
+                result = io.BytesIO()
                 for key in chunk_keys:
                     result.write(fixture_objects[key].getvalue())
             else:
@@ -190,7 +191,7 @@ class SwiftTests(object):
 
             if byte_range is not None:
                 start = int(byte_range.split('=')[1].strip('-'))
-                result = six.BytesIO(result.getvalue()[start:])
+                result = io.BytesIO(result.getvalue()[start:])
                 fixture_headers[fixture_key]['content-length'] = len(
                     result.getvalue())
 
@@ -203,7 +204,7 @@ class SwiftTests(object):
                 return fixture_headers[fixture_key]
             except KeyError:
                 msg = "Object HEAD failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
         def fake_delete_object(url, token, container, name, **kwargs):
@@ -211,7 +212,7 @@ class SwiftTests(object):
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object DELETE failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             else:
                 del fixture_headers[fixture_key]
@@ -339,7 +340,7 @@ class SwiftTests(object):
         (image_swift, image_size) = self.store.get(loc, context=ctxt)
         resp_full = b''.join([chunk for chunk in image_swift.wrapped])
         resp_half = resp_full[:len(resp_full) // 2]
-        resp_half = six.BytesIO(resp_half)
+        resp_half = io.BytesIO(resp_half)
         manager = self.store.get_manager(loc.store_location, ctxt)
 
         image_swift.wrapped = swift.swift_retry_iter(resp_half, image_size,
@@ -415,19 +416,20 @@ class SwiftTests(object):
                 mock.Mock(return_value=False))
     def test_add(self):
         """Test that we can add an image via the swift backend."""
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf)
         self.store.configure()
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(
             expected_swift_contents).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = "swift+https://tenant%%3Auser1:key@localhost:8080/glance/%s"
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -456,7 +458,7 @@ class SwiftTests(object):
         conf = copy.deepcopy(SWIFT_CONF)
         conf['default_swift_reference'] = 'store_2'
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf)
         self.store.configure()
@@ -464,7 +466,7 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
         expected_image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
         loc = 'swift+config://store_2/glance/%s'
@@ -475,6 +477,33 @@ class SwiftTests(object):
             expected_image_id, image_swift, expected_swift_size, HASH_ALGO)
         self.assertEqual(expected_location, location)
 
+    def test_add_raises_storage_full(self):
+
+        conf = copy.deepcopy(SWIFT_CONF)
+        conf['default_swift_reference'] = 'store_2'
+        self.config(**conf)
+        importlib.reload(swift)
+        self.mock_keystone_client()
+        self.store = Store(self.conf)
+        self.store.configure()
+
+        def fake_put_object_entity_too_large(*args, **kwargs):
+            msg = "Test Out of Quota"
+            raise swiftclient.ClientException(
+                msg, http_status=http.client.REQUEST_ENTITY_TOO_LARGE)
+
+        self.useFixture(fixtures.MockPatch(
+            'swiftclient.client.put_object', fake_put_object_entity_too_large))
+
+        expected_swift_size = FIVE_KB
+        expected_swift_contents = b"*" * expected_swift_size
+        expected_image_id = str(uuid.uuid4())
+        image_swift = io.BytesIO(expected_swift_contents)
+
+        self.assertRaises(exceptions.StorageFull, self.store.add,
+                          expected_image_id, image_swift,
+                          expected_swift_size, HASH_ALGO)
+
     @mock.patch('glance_store._drivers.swift.utils'
                 '.is_multiple_swift_store_accounts_enabled',
                 mock.Mock(return_value=False))
@@ -485,7 +514,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -542,17 +571,17 @@ class SwiftTests(object):
             expected_swift_size = FIVE_KB
             expected_swift_contents = b"*" * expected_swift_size
             expected_checksum = \
-                hashlib.md5(expected_swift_contents).hexdigest()
+                md5(expected_swift_contents, usedforsecurity=False).hexdigest()
             expected_multihash = \
                 hashlib.sha256(expected_swift_contents).hexdigest()
 
-            image_swift = six.BytesIO(expected_swift_contents)
+            image_swift = io.BytesIO(expected_swift_contents)
 
             global SWIFT_PUT_OBJECT_CALLS
             SWIFT_PUT_OBJECT_CALLS = 0
             conf['default_swift_reference'] = variation
             self.config(**conf)
-            moves.reload_module(swift)
+            importlib.reload(swift)
             self.mock_keystone_client()
             self.store = Store(self.conf)
             self.store.configure()
@@ -584,13 +613,13 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = False
         conf['swift_store_container'] = 'noexist'
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf)
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -618,13 +647,14 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = \
             hashlib.sha256(expected_swift_contents).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/noexist/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -633,7 +663,7 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = True
         conf['swift_store_container'] = 'noexist'
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf)
         self.store.configure()
@@ -664,14 +694,15 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = \
             hashlib.sha256(expected_swift_contents).hexdigest()
         expected_image_id = str(uuid.uuid4())
         container = 'randomname_' + expected_image_id[:2]
         loc = 'swift+config://ref1/%s/%s'
         expected_location = loc % (container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -681,7 +712,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf)
@@ -717,7 +748,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         expected_image_id = str(uuid.uuid4())
@@ -726,7 +757,7 @@ class SwiftTests(object):
         self.store = Store(self.conf)
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -754,7 +785,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf)
         self.store.configure()
@@ -801,7 +832,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf)
         self.store.configure()
@@ -840,7 +871,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -885,13 +916,14 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = \
             hashlib.sha256(expected_swift_contents).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -939,13 +971,14 @@ class SwiftTests(object):
         # Set up a 'large' image of 5KB
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_multihash = \
             hashlib.sha256(expected_swift_contents).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -992,7 +1025,7 @@ class SwiftTests(object):
         """
         self.store = Store(self.conf)
         self.store.configure()
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
         self.assertRaises(exceptions.Duplicate,
                           self.store.add,
                           FAKE_UUID, image_swift, 0, HASH_ALGO)
@@ -1039,7 +1072,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf)
         self.store.configure()
@@ -1058,7 +1091,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf)
         self.store.configure()
 
@@ -1079,7 +1112,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf)
         self.store.configure()
@@ -1099,7 +1132,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         # mock client because v3 uses it to receive auth_info
         self.mock_keystone_client()
         self.store = Store(self.conf)
@@ -1118,7 +1151,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf)
         self.store.configure()
 
@@ -1157,7 +1190,7 @@ class SwiftTests(object):
 
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf)
         self.store.configure()
 
@@ -1526,6 +1559,31 @@ class TestSingleTenantStoreConnections(base.StoreBaseTest):
                           'endpoint_type': 'publicURL'},
                          connection.os_options)
 
+    @mock.patch("keystoneauth1.session.Session.get_endpoint")
+    @mock.patch("keystoneauth1.session.Session.get_auth_headers",
+                new=mock.Mock())
+    def _test_connection_manager_authv3_conf_endpoint(
+            self, mock_ep, expected_endpoint="https://from-catalog.com"):
+        self.config(swift_store_auth_version='3')
+        mock_ep.return_value = "https://from-catalog.com"
+        ctx = mock.MagicMock()
+        self.store.configure()
+        connection_manager = manager.SingleTenantConnectionManager(
+            store=self.store,
+            store_location=self.location,
+            context=ctx
+        )
+        conn = connection_manager._init_connection()
+        self.assertEqual(expected_endpoint, conn.preauthurl)
+
+    def test_connection_manager_authv3_without_conf_endpoint(self):
+        self._test_connection_manager_authv3_conf_endpoint()
+
+    def test_connection_manager_authv3_with_conf_endpoint(self):
+        self.config(swift_store_endpoint='http://localhost')
+        self._test_connection_manager_authv3_conf_endpoint(
+            expected_endpoint='http://localhost')
+
     def test_connection_with_no_trailing_slash(self):
         self.location.auth_or_store_url = 'example.com/v2'
         connection = self.store.get_connection(self.location)
@@ -1787,7 +1845,7 @@ class TestMultiTenantStoreContext(base.StoreBaseTest):
         store = Store(self.conf)
         store.configure()
         content = b'Some data'
-        pseudo_file = six.BytesIO(content)
+        pseudo_file = io.BytesIO(content)
         store.add('123', pseudo_file, len(content), HASH_ALGO,
                   context=self.ctx)
         self.assertEqual(b'0123',
@@ -1804,7 +1862,7 @@ class TestCreatingLocations(base.StoreBaseTest):
         conf = copy.deepcopy(SWIFT_CONF)
         self.store = Store(self.conf)
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.addCleanup(self.conf.reset)
 
         service_catalog = [
@@ -1834,7 +1892,7 @@ class TestCreatingLocations(base.StoreBaseTest):
         conf.update({'swift_store_config_file': self.swift_config_file})
         conf['default_swift_reference'] = 'ref1'
         self.config(**conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
 
         store = swift.SingleTenantStore(self.conf)
         store.configure()
@@ -1922,14 +1980,14 @@ class TestChunkReader(base.StoreBaseTest):
         """
         CHUNKSIZE = 100
         data = b'*' * units.Ki
-        expected_checksum = hashlib.md5(data).hexdigest()
+        expected_checksum = md5(data, usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(data).hexdigest()
         data_file = tempfile.NamedTemporaryFile()
         data_file.write(data)
         data_file.flush()
         infile = open(data_file.name, 'rb')
         bytes_read = 0
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         while True:
             cr = swift.ChunkReader(infile, checksum, os_hash_value, CHUNKSIZE)
@@ -1951,10 +2009,10 @@ class TestChunkReader(base.StoreBaseTest):
         Replicate what goes on in the Swift driver with the
         repeated creation of the ChunkReader object
         """
-        expected_checksum = hashlib.md5(b'').hexdigest()
+        expected_checksum = md5(b'', usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(b'').hexdigest()
         CHUNKSIZE = 100
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         data_file = tempfile.NamedTemporaryFile()
         infile = open(data_file.name, 'rb')
@@ -2047,10 +2105,10 @@ class TestBufferedReader(base.StoreBaseTest):
         super(TestBufferedReader, self).setUp()
         self.config(swift_upload_buffer_dir=self.test_dir)
         s = b'1234567890'
-        self.infile = six.BytesIO(s)
+        self.infile = io.BytesIO(s)
         self.infile.seek(0)
 
-        self.checksum = hashlib.md5()
+        self.checksum = md5(usedforsecurity=False)
         self.hash_algo = HASH_ALGO
         self.os_hash_value = hashlib.sha256()
         self.verifier = mock.MagicMock(name='mock_verifier')
@@ -2110,7 +2168,7 @@ class TestBufferedReader(base.StoreBaseTest):
 
     def test_checksums(self):
         # checksums are updated only once on a full segment read
-        expected_csum = hashlib.md5()
+        expected_csum = md5(usedforsecurity=False)
         expected_csum.update(b'1234567')
         expected_multihash = hashlib.sha256()
         expected_multihash.update(b'1234567')
@@ -2122,7 +2180,7 @@ class TestBufferedReader(base.StoreBaseTest):
     def test_checksum_updated_only_once_w_full_segment_read(self):
         # Test that checksums are updated only once when a full segment read
         # is followed by a seek and partial reads.
-        expected_csum = hashlib.md5()
+        expected_csum = md5(usedforsecurity=False)
         expected_csum.update(b'1234567')
         expected_multihash = hashlib.sha256()
         expected_multihash.update(b'1234567')
@@ -2137,7 +2195,7 @@ class TestBufferedReader(base.StoreBaseTest):
     def test_checksum_updates_during_partial_segment_reads(self):
         # Test to check that checksums are updated with only the bytes
         # not seen when the number of bytes being read is changed
-        expected_csum = hashlib.md5()
+        expected_csum = md5(usedforsecurity=False)
         expected_multihash = hashlib.sha256()
         self.reader.read(4)
         expected_csum.update(b'1234')
@@ -2160,7 +2218,7 @@ class TestBufferedReader(base.StoreBaseTest):
 
     def test_checksum_rolling_calls(self):
         # Test that the checksum continues on to the next segment
-        expected_csum = hashlib.md5()
+        expected_csum = md5(usedforsecurity=False)
         expected_multihash = hashlib.sha256()
         self.reader.read(7)
         expected_csum.update(b'1234567')
@@ -2226,10 +2284,10 @@ class TestBufferedReader(base.StoreBaseTest):
         # simulate testing where there is less in the buffer than a
         # full segment
         s = b'12'
-        infile = six.BytesIO(s)
+        infile = io.BytesIO(s)
         infile.seek(0)
         total = 7
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         self.reader = buffered.BufferedReader(
             infile, checksum, os_hash_value, total)
@@ -2254,14 +2312,14 @@ class TestBufferedReader(base.StoreBaseTest):
         """
         CHUNKSIZE = 100
         data = b'*' * units.Ki
-        expected_checksum = hashlib.md5(data).hexdigest()
+        expected_checksum = md5(data, usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(data).hexdigest()
         data_file = tempfile.NamedTemporaryFile()
         data_file.write(data)
         data_file.flush()
         infile = open(data_file.name, 'rb')
         bytes_read = 0
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         while True:
             cr = buffered.BufferedReader(infile, checksum, os_hash_value,
