@@ -20,18 +20,17 @@ from unittest import mock
 
 import fixtures
 import hashlib
+import http.client
+import importlib
+import io
 import tempfile
 import uuid
 
 from oslo_config import cfg
 from oslo_utils import encodeutils
+from oslo_utils.secretutils import md5
 from oslo_utils import units
 import requests_mock
-import six
-from six import moves
-from six.moves import http_client
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
-from six.moves import range
 import swiftclient
 
 from glance_store._drivers.swift import connection_manager as manager
@@ -83,14 +82,14 @@ class SwiftTests(object):
             'glance/%s' % FAKE_UUID2: {'x-static-large-object': 'true', },
         }
         fixture_objects = {
-            'glance/%s' % FAKE_UUID: six.BytesIO(b"*" * FIVE_KB),
-            'glance/%s' % FAKE_UUID2: six.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID: io.BytesIO(b"*" * FIVE_KB),
+            'glance/%s' % FAKE_UUID2: io.BytesIO(b"*" * FIVE_KB),
         }
 
         def fake_head_container(url, token, container, **kwargs):
             if container not in fixture_containers:
                 msg = "No container %s found" % container
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             return fixture_container_headers
 
@@ -112,7 +111,8 @@ class SwiftTests(object):
                 if kwargs.get('headers'):
                     manifest = kwargs.get('headers').get('X-Object-Manifest')
                     etag = kwargs.get('headers') \
-                                 .get('ETag', hashlib.md5(b'').hexdigest())
+                                 .get('ETag', md5(
+                                     b'', usedforsecurity=False).hexdigest())
                     fixture_headers[fixture_key] = {
                         'manifest': True,
                         'etag': etag,
@@ -121,10 +121,10 @@ class SwiftTests(object):
                     fixture_objects[fixture_key] = None
                     return etag
                 if hasattr(contents, 'read'):
-                    fixture_object = six.BytesIO()
+                    fixture_object = io.BytesIO()
                     read_len = 0
                     chunk = contents.read(CHUNKSIZE)
-                    checksum = hashlib.md5()
+                    checksum = md5(usedforsecurity=False)
                     while chunk:
                         fixture_object.write(chunk)
                         read_len += len(chunk)
@@ -132,14 +132,15 @@ class SwiftTests(object):
                         chunk = contents.read(CHUNKSIZE)
                     etag = checksum.hexdigest()
                 else:
-                    fixture_object = six.BytesIO(contents)
+                    fixture_object = io.BytesIO(contents)
                     read_len = len(contents)
-                    etag = hashlib.md5(fixture_object.getvalue()).hexdigest()
+                    etag = md5(fixture_object.getvalue(),
+                               usedforsecurity=False).hexdigest()
                 if read_len > MAX_SWIFT_OBJECT_SIZE:
                     msg = ('Image size:%d exceeds Swift max:%d' %
                            (read_len, MAX_SWIFT_OBJECT_SIZE))
                     raise swiftclient.ClientException(
-                        msg, http_status=http_client.REQUEST_ENTITY_TOO_LARGE)
+                        msg, http_status=http.client.REQUEST_ENTITY_TOO_LARGE)
                 fixture_objects[fixture_key] = fixture_object
                 fixture_headers[fixture_key] = {
                     'content-length': read_len,
@@ -149,14 +150,14 @@ class SwiftTests(object):
                 msg = ("Object PUT failed - Object with key %s already exists"
                        % fixture_key)
                 raise swiftclient.ClientException(
-                    msg, http_status=http_client.CONFLICT)
+                    msg, http_status=http.client.CONFLICT)
 
         def fake_get_object(conn, container, name, **kwargs):
             # GET returns the tuple (list of headers, file object)
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object GET failed"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
             byte_range = None
@@ -173,7 +174,7 @@ class SwiftTests(object):
                 chunk_keys = sorted([k for k in fixture_headers.keys()
                                      if k.startswith(fixture_key) and
                                      k != fixture_key])
-                result = six.BytesIO()
+                result = io.BytesIO()
                 for key in chunk_keys:
                     result.write(fixture_objects[key].getvalue())
             else:
@@ -181,7 +182,7 @@ class SwiftTests(object):
 
             if byte_range is not None:
                 start = int(byte_range.split('=')[1].strip('-'))
-                result = six.BytesIO(result.getvalue()[start:])
+                result = io.BytesIO(result.getvalue()[start:])
                 fixture_headers[fixture_key]['content-length'] = len(
                     result.getvalue())
 
@@ -194,7 +195,7 @@ class SwiftTests(object):
                 return fixture_headers[fixture_key]
             except KeyError:
                 msg = "Object HEAD failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
 
         def fake_delete_object(url, token, container, name, **kwargs):
@@ -202,7 +203,7 @@ class SwiftTests(object):
             fixture_key = "%s/%s" % (container, name)
             if fixture_key not in fixture_headers:
                 msg = "Object DELETE failed - Object does not exist"
-                status = http_client.NOT_FOUND
+                status = http.client.NOT_FOUND
                 raise swiftclient.ClientException(msg, http_status=status)
             else:
                 del fixture_headers[fixture_key]
@@ -314,7 +315,7 @@ class SwiftTests(object):
         (image_swift, image_size) = self.store.get(loc, context=ctxt)
         resp_full = b''.join([chunk for chunk in image_swift.wrapped])
         resp_half = resp_full[:len(resp_full) // 2]
-        resp_half = six.BytesIO(resp_half)
+        resp_half = io.BytesIO(resp_half)
         manager = self.store.get_manager(loc.store_location, ctxt)
 
         image_swift.wrapped = swift.swift_retry_iter(resp_half, image_size,
@@ -390,17 +391,18 @@ class SwiftTests(object):
                 mock.Mock(return_value=False))
     def test_add(self):
         """Test that we can add an image via the swift backend."""
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = "swift+https://tenant%%3Auser1:key@localhost:8080/glance/%s"
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -429,7 +431,7 @@ class SwiftTests(object):
         conf = copy.deepcopy(SWIFT_CONF)
         conf['default_swift_reference'] = 'store_2'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -437,7 +439,7 @@ class SwiftTests(object):
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
         expected_image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
         loc = 'swift+config://store_2/glance/%s'
@@ -460,7 +462,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -520,15 +522,15 @@ class SwiftTests(object):
             expected_swift_size = FIVE_KB
             expected_swift_contents = b"*" * expected_swift_size
             expected_checksum = \
-                hashlib.md5(expected_swift_contents).hexdigest()
+                md5(expected_swift_contents, usedforsecurity=False).hexdigest()
 
-            image_swift = six.BytesIO(expected_swift_contents)
+            image_swift = io.BytesIO(expected_swift_contents)
 
             global SWIFT_PUT_OBJECT_CALLS
             SWIFT_PUT_OBJECT_CALLS = 0
             conf['default_swift_reference'] = variation
             self.config(group="swift1", **conf)
-            moves.reload_module(swift)
+            importlib.reload(swift)
             self.mock_keystone_client()
             self.store = Store(self.conf, backend="swift1")
             self.store.configure()
@@ -561,13 +563,13 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = False
         conf['swift_store_container'] = 'noexist'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf, backend='swift1')
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -595,11 +597,12 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/noexist/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -608,7 +611,7 @@ class SwiftTests(object):
         conf['swift_store_create_container_on_put'] = True
         conf['swift_store_container'] = 'noexist'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -641,12 +644,13 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         container = 'randomname_' + expected_image_id[:2]
         loc = 'swift+config://ref1/%s/%s'
         expected_location = loc % (container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -656,7 +660,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         self.store = Store(self.conf, backend="swift1")
@@ -694,7 +698,7 @@ class SwiftTests(object):
         conf['swift_store_container'] = 'randomname'
         conf['swift_store_multiple_containers_seed'] = 2
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
 
         expected_image_id = str(uuid.uuid4())
@@ -703,7 +707,7 @@ class SwiftTests(object):
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -731,7 +735,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -778,7 +782,7 @@ class SwiftTests(object):
         base_byte = b"12345678"
         swift_contents = base_byte * (swift_size // 8)
         image_id = str(uuid.uuid4())
-        image_swift = six.BytesIO(swift_contents)
+        image_swift = io.BytesIO(swift_contents)
 
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -817,7 +821,7 @@ class SwiftTests(object):
         expected_container = 'container_' + expected_image_id
         loc = 'swift+https://some_endpoint/%s/%s'
         expected_location = loc % (expected_container, expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -865,11 +869,12 @@ class SwiftTests(object):
         """
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -919,11 +924,12 @@ class SwiftTests(object):
         # Set up a 'large' image of 5KB
         expected_swift_size = FIVE_KB
         expected_swift_contents = b"*" * expected_swift_size
-        expected_checksum = hashlib.md5(expected_swift_contents).hexdigest()
+        expected_checksum = md5(expected_swift_contents,
+                                usedforsecurity=False).hexdigest()
         expected_image_id = str(uuid.uuid4())
         loc = 'swift+config://ref1/glance/%s'
         expected_location = loc % (expected_image_id)
-        image_swift = six.BytesIO(expected_swift_contents)
+        image_swift = io.BytesIO(expected_swift_contents)
 
         global SWIFT_PUT_OBJECT_CALLS
         SWIFT_PUT_OBJECT_CALLS = 0
@@ -978,7 +984,7 @@ class SwiftTests(object):
         """
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
-        image_swift = six.BytesIO(b"nevergonnamakeit")
+        image_swift = io.BytesIO(b"nevergonnamakeit")
         self.assertRaises(exceptions.Duplicate,
                           self.store.add,
                           FAKE_UUID, image_swift, 0)
@@ -1025,7 +1031,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -1045,7 +1051,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1067,7 +1073,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
@@ -1088,7 +1094,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         # mock client because v3 uses it to receive auth_info
         self.mock_keystone_client()
         self.store = Store(self.conf, backend="swift1")
@@ -1108,7 +1114,7 @@ class SwiftTests(object):
         """
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1147,7 +1153,7 @@ class SwiftTests(object):
 
         conf = copy.deepcopy(SWIFT_CONF)
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.store = Store(self.conf, backend="swift1")
         self.store.configure()
 
@@ -1888,7 +1894,7 @@ class TestMultiTenantStoreContext(base.MultiStoreBaseTest):
         store = Store(self.conf, backend="swift1")
         store.configure()
         content = b'Some data'
-        pseudo_file = six.BytesIO(content)
+        pseudo_file = io.BytesIO(content)
         store.add('123', pseudo_file, len(content),
                   context=self.ctx)
         self.assertEqual(b'0123',
@@ -1931,7 +1937,7 @@ class TestCreatingLocations(base.MultiStoreBaseTest):
         self.store.configure()
         self.register_store_backend_schemes(self.store, 'swift', 'swift1')
 
-        moves.reload_module(swift)
+        importlib.reload(swift)
         self.addCleanup(self.conf.reset)
 
         service_catalog = [
@@ -1961,7 +1967,7 @@ class TestCreatingLocations(base.MultiStoreBaseTest):
         conf.update({'swift_store_config_file': self.swift_config_file})
         conf['default_swift_reference'] = 'ref1'
         self.config(group="swift1", **conf)
-        moves.reload_module(swift)
+        importlib.reload(swift)
 
         store = swift.SingleTenantStore(self.conf, backend="swift1")
         store.configure()
@@ -2076,14 +2082,14 @@ class TestChunkReader(base.MultiStoreBaseTest):
         """
         CHUNKSIZE = 100
         data = b'*' * units.Ki
-        expected_checksum = hashlib.md5(data).hexdigest()
+        expected_checksum = md5(data, usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(data).hexdigest()
         data_file = tempfile.NamedTemporaryFile()
         data_file.write(data)
         data_file.flush()
         infile = open(data_file.name, 'rb')
         bytes_read = 0
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         while True:
             cr = swift.ChunkReader(infile, checksum, os_hash_value, CHUNKSIZE)
@@ -2105,10 +2111,10 @@ class TestChunkReader(base.MultiStoreBaseTest):
         Replicate what goes on in the Swift driver with the
         repeated creation of the ChunkReader object
         """
-        expected_checksum = hashlib.md5(b'').hexdigest()
+        expected_checksum = md5(b'', usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(b'').hexdigest()
         CHUNKSIZE = 100
-        checksum = hashlib.md5()
+        checksum = md5(usedforsecurity=False)
         os_hash_value = hashlib.sha256()
         data_file = tempfile.NamedTemporaryFile()
         infile = open(data_file.name, 'rb')
